@@ -25,3 +25,10 @@ pn.Column(
     pn.panel(plot_output, height=400, sizing_mode="stretch_both", align="center"),
     sizing_mode="stretch_both",
 ).servable()
+
+pn.state.template.param.update(
+    site="Awesome Panel Sharing",
+    site_url="https://awesome-panel.org/sharing",
+    favicon="https://raw.githubusercontent.com/MarcSkovMadsen/awesome-panel-assets/320297ccb92773da099f6b97d267cc0433b67c23/favicon/ap-1f77b4.ico",
+    title="Bokeh Matplotlib App",
+)
